/***************************************************************************
                          ann_to_offline.cpp  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_to_offline.h>

  //                       //
 // class ANN::TO_offline //
//                       //

ANN::TO_offline::~TO_offline()
{
}

ANN::NE::Status
ANN::TO_offline::adapt_internal()
{
  if (log) log->open(epoch);
  trainee->open();
  ds->reset();
  for (size_t i=0, l=ds->get_length(); i<l; ++i)
  {
    if (i) ds->feed();
    if (log) log->feed(ds->which(),&ds->where());
    trainee->adapt(ds->term(),out_data);
  }
  if (log) log->feed(size_max,0);
  ws->commit(*this);
  Status ret=trainee->close();
  if (log) log->close(epoch);
  return ret;
}

